/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.ws.resource.impl;

import org.apache.muse.core.Resource;
import org.apache.muse.core.routing.SimpleResourceRouter;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.resource.faults.ResourceUnknownFault;

/**
 *
 * WsResourceRouter is a sub-class of SimpleResourceRouter that wraps all 
 * WS-A DestinationUnreachable faults in a WS-RF ResourceUnknownFault. These 
 * two faults have the same functional role, but WS-RF messages advertise 
 * the ResourceUnknownFault, so we use it instead of the WS-A fault.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class WsResourceRouter extends SimpleResourceRouter
{
    protected Resource getTargetResource()
        throws SoapFault
    {
        try
        {
            return super.getTargetResource();
        }
        
        catch (SoapFault error)
        {
            throw new ResourceUnknownFault(error);
        }
    }
}
