/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.ws.resource.metadata.impl;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.ws.resource.basefaults.BaseFault;
import org.apache.muse.ws.resource.properties.listeners.AbstractChangeApprover;
import org.apache.muse.ws.resource.properties.listeners.PropertyChangeApprover;
import org.apache.muse.ws.resource.properties.set.faults.UnableToModifyResourcePropertyFault;

/**
 *
 * ReadOnlyApprover is a {@linkplain PropertyChangeApprover PropertyChangeApprover} 
 * that prevents modifications to read-only properties. It throws an exception for 
 * any and all attempts to change a property.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class ReadOnlyApprover extends AbstractChangeApprover
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = MessagesFactory.get(ReadOnlyApprover.class);
    
    public ReadOnlyApprover(QName qname)
    {
        super(qname);
    }
    
    /**
     * 
     * <b>Always</b> throws an exception - <b>no</b> changes are allowed for 
     * read-only properties.
     *
     */
    public void validateChange(Element oldValue, Element newValue, Object token) 
        throws BaseFault
    {
        //
        // any change = BAD
        //
        throw new UnableToModifyResourcePropertyFault(_MESSAGES.get("ReadOnly", new Object[]{ getPropertyName() }));
    }
}
