/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.ws.resource.properties.get.impl;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import org.apache.muse.core.routing.AbstractMessageHandler;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.resource.properties.WsrpConstants;

/**
 *
 * GetDocumentHandler is the parser for the WS-ResourceProperties 
 * GetResourcePropertyDocument operation.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class GetDocumentHandler extends AbstractMessageHandler
{
    public GetDocumentHandler()
    {
        super(WsrpConstants.GET_RP_DOCUMENT_URI, WsrpConstants.GET_DOCUMENT_QNAME);
    }

    public Object[] fromXML(Element xml)
    {
        return EMPTY_REQUEST;
    }

    public Element toXML(Object result)
    {
        Element resultXML = (Element)result;
        Document doc = resultXML.getOwnerDocument();
        
        Node parent = resultXML.getParentNode();
        
        if (parent != null)
            parent.removeChild(resultXML);
        
        return XmlUtils.createElement(doc, WsrpConstants.GET_DOCUMENT_RESPONSE_QNAME, resultXML, false);
    }
}
