/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.ws.resource.properties.query.impl;

import java.util.Arrays;
import java.util.Collection;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.ws.resource.properties.query.QueryExpression;
import org.apache.muse.ws.resource.properties.query.QueryExpressionFactory;
import org.apache.muse.ws.resource.properties.query.faults.UnknownQueryExpressionDialectFault;

/**
 * 
 * XPathQueryExpressionFactory can create query expressions that support XPath 1.0.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class XPathQueryExpressionFactory implements QueryExpressionFactory
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = MessagesFactory.get(XPathQueryExpressionFactory.class);
    
    //
    // only need one of these, since it's stateless
    //
    private static final QueryExpression _EVALUATOR = new XPathQueryExpression();
    
    //
    // we only support one dialect - make a static collection
    //
    private static final Collection _DIALECTS = Arrays.asList(new Object[]{ _EVALUATOR.getDialect() });
    
    public Collection getDialects()
    {
        return _DIALECTS;
    }
    
    public QueryExpression newInstance(String dialect)
        throws UnknownQueryExpressionDialectFault
    {
        //
        // this implementation only supports XPath queries
        //
        if (dialect == null || !dialect.equals(_EVALUATOR.getDialect()))
        {
            Object[] filler = { dialect, _EVALUATOR.getDialect() };
            throw new UnknownQueryExpressionDialectFault(_MESSAGES.get("UnknownQueryDialect", filler));
        }

        return _EVALUATOR;
    }
}
