/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.ws.resource.sg.impl;

import org.w3c.dom.Element;

import org.apache.muse.core.routing.AbstractMessageHandler;
import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.resource.sg.WssgConstants;
import org.apache.muse.ws.addressing.soap.SoapFault;

/**
 *
 * AddHandler is the parser for the WS-ServiceGroup Add operation.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class AddHandler extends AbstractMessageHandler
{
    public AddHandler()
    {
        super(WssgConstants.ADD_URI, WssgConstants.ADD_QNAME);
    }

    public Object[] fromXML(Element xml) 
        throws SoapFault
    {
        AddRequest add = new AddRequest(xml);
        return new Object[]{ add.getMemberEPR(), add.getContent(), add.getTerminationTime() };
    }

    public Element toXML(Object result)
    {
        AddResponse response = new AddResponse((EndpointReference)result);
        return response.toXML();
    }
}
